@@ -45,9 +45,9 @@ def add_required_elements_to_ds(ds: FileDataset):
     ds.StructureSetDate = dt.strftime('%Y%m%d')
     ds.StructureSetTime = dt.strftime('%H%M%S.%f')
     ds.Modality = 'RTSTRUCT'
-    ds.Manufacturer = 'Qurit Lab'
+    ds.Manufacturer = 'Qurit'
     ds.ManufacturerModelName = 'rt-utils'
-    ds.InstitutionName = 'BC Cancer Research Center'
+    ds.InstitutionName = 'Qurit'
     # Set the transfer syntax
     ds.is_little_endian = True
     ds.is_implicit_VR = True
@@ -65,9 +65,9 @@ def add_sequence_lists_to_ds(ds: FileDataset):
 def add_study_and_series_information(ds: FileDataset, series_data):
     reference_ds = series_data[0] # All elements in series should have the same data
     ds.StudyDate = reference_ds.StudyDate
-    ds.SeriesDate = reference_ds.SeriesDate
+    ds.SeriesDate = getattr(reference_ds, 'SeriesDate', '')
     ds.StudyTime = reference_ds.StudyTime
-    ds.SeriesTime = reference_ds.SeriesTime
+    ds.SeriesTime = getattr(reference_ds, 'SeriesTime', '')
     ds.StudyDescription = getattr(reference_ds, 'StudyDescription', '')
     ds.SeriesDescription = getattr(reference_ds, 'SeriesDescription', '')
     ds.StudyInstanceUID = reference_ds.StudyInstanceUID
@@ -160,7 +160,7 @@ def create_contour_sequence(roi_data: ROIData, series_data) -> Sequence:
             print("Skipping empty mask layer")
             continue
 
-        contour_coords = get_contours_coords(mask_slice, series_slice, roi_data.use_pin_hole)
+        contour_coords = get_contours_coords(mask_slice, series_slice, roi_data)
         for contour_data in contour_coords:
             contour = create_contour(series_slice, contour_data)
             contour_sequence.append(contour)
